package com.mall.product.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;
import com.mall.product.domain.dto.CategoryBrandRelationDto;
import com.mall.product.domain.entity.CategoryBrandRelation;
import com.mall.product.domain.vo.CategoryBrandRelationVo;
import com.mall.product.service.CategoryBrandRelationService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 品牌分类关联 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 15:19:19
 */
@Tag(name = "品牌分类关联", description = "品牌分类关联相关接口")
@RestController
@RequestMapping("/api/product/categoryBrandRelation")
@RequiredArgsConstructor
public class CategoryBrandRelationController {

    private final CategoryBrandRelationService categoryBrandRelationService;

    @Operation(summary = "分页查询品牌分类关联", description = "分页品牌分类关联")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<CategoryBrandRelationVo>> getCategoryBrandRelationPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            CategoryBrandRelationDto dto) {
        Page<CategoryBrandRelation> pageParams = new Page<>(page, limit);
        PageResult<CategoryBrandRelationVo> pageResult = categoryBrandRelationService.getCategoryBrandRelationPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加品牌分类关联", description = "添加品牌分类关联")
    @PostMapping()
    public Result<String> addCategoryBrandRelation(@Valid @RequestBody CategoryBrandRelationDto dto) {
        categoryBrandRelationService.addCategoryBrandRelation(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新品牌分类关联", description = "更新品牌分类关联")
    @PutMapping()
    public Result<String> updateCategoryBrandRelation(@Valid @RequestBody CategoryBrandRelationDto dto) {
        categoryBrandRelationService.updateCategoryBrandRelation(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除品牌分类关联", description = "删除品牌分类关联")
    @DeleteMapping()
    public Result<String> deleteCategoryBrandRelation(@RequestBody List<Long> ids) {
        categoryBrandRelationService.deleteCategoryBrandRelation(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}