package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.SkuImagesDto;
import com.mall.product.domain.entity.SkuImages;
import com.mall.product.domain.vo.SkuImagesVo;
import com.mall.product.mapper.SkuImagesMapper;
import com.mall.product.service.SkuImagesService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * sku图片 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class SkuImagesServiceImpl extends ServiceImpl<SkuImagesMapper, SkuImages> implements SkuImagesService {

    /**
     * * sku图片 服务实现类
     *
     * @param pageParams sku图片分页查询page对象
     * @param dto        sku图片分页查询对象
     * @return 查询分页sku图片返回对象
     */
    @Override
    public PageResult<SkuImagesVo> getSkuImagesPage(Page<SkuImages> pageParams, SkuImagesDto dto) {
        IPage<SkuImagesVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<SkuImagesVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加sku图片
     *
     * @param dto sku图片添加
     */
    @Override
    public void addSkuImages(SkuImagesDto dto) {
        SkuImages skuImages = new SkuImages();
        BeanUtils.copyProperties(dto, skuImages);
        save(skuImages);
    }

    /**
     * 更新sku图片
     *
     * @param dto sku图片更新
     */
    @Override
    public void updateSkuImages(SkuImagesDto dto) {
        SkuImages skuImages = new SkuImages();
        BeanUtils.copyProperties(dto, skuImages);
        updateById(skuImages);
    }

    /**
     * 删除|批量删除sku图片
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteSkuImages(List<Long> ids) {
        removeByIds(ids);
    }
}